@@ -2,12 +2,10 @@
  *
  * Copyright (C) 2008-2010 Red Hat, Inc.
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +13,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author: David Zeuthen <davidz@redhat.com>
  */
@@ -29,8 +29,7 @@
 #include "gdbusprivate.h"
 #include "gdbusmethodinvocation.h"
 #include "gdbusconnection.h"
-#include "gmarshal-internal.h"
-#include "gtask.h"
+#include "gioscheduler.h"
 #include "gioerror.h"
 
 #include "glibintl.h"
@@ -45,21 +44,14 @@
 
 struct _GDBusInterfaceSkeletonPrivate
 {
-  GMutex                      lock;
-
-  GDBusObject                *object;
+  GDBusObject *object;
   GDBusInterfaceSkeletonFlags flags;
+  guint registration_id;
 
-  GSList                     *connections;   /* List of ConnectionData */
-  gchar                      *object_path;   /* The object path for this skeleton */
-  GDBusInterfaceVTable       *hooked_vtable;
-};
-
-typedef struct
-{
   GDBusConnection *connection;
-  guint            registration_id;
-} ConnectionData;
+  gchar *object_path;
+  GDBusInterfaceVTable *hooked_vtable;
+};
 
 enum
 {
@@ -75,52 +67,25 @@ enum
 
 static guint signals[LAST_SIGNAL] = {0};
 
-static void     dbus_interface_interface_init                      (GDBusInterfaceIface    *iface);
-
-static void     set_object_path_locked                             (GDBusInterfaceSkeleton *interface_,
-                                                                    const gchar            *object_path);
-static void     remove_connection_locked                           (GDBusInterfaceSkeleton *interface_,
-                                                                    GDBusConnection        *connection);
-static void     skeleton_intercept_handle_method_call              (GDBusConnection        *connection,
-                                                                    const gchar            *sender,
-                                                                    const gchar            *object_path,
-                                                                    const gchar            *interface_name,
-                                                                    const gchar            *method_name,
-                                                                    GVariant               *parameters,
-                                                                    GDBusMethodInvocation  *invocation,
-                                                                    gpointer                user_data);
-
+static void dbus_interface_interface_init (GDBusInterfaceIface *iface);
 
 G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GDBusInterfaceSkeleton, g_dbus_interface_skeleton, G_TYPE_OBJECT,
-                                  G_ADD_PRIVATE (GDBusInterfaceSkeleton)
-                                  G_IMPLEMENT_INTERFACE (G_TYPE_DBUS_INTERFACE, dbus_interface_interface_init))
+                                  G_IMPLEMENT_INTERFACE (G_TYPE_DBUS_INTERFACE, dbus_interface_interface_init));
 
 static void
 g_dbus_interface_skeleton_finalize (GObject *object)
 {
   GDBusInterfaceSkeleton *interface = G_DBUS_INTERFACE_SKELETON (object);
+  /* unexport if already exported */
+  if (interface->priv->registration_id > 0)
+    g_dbus_interface_skeleton_unexport (interface);
 
-  /* Hold the lock just in case any code we call verifies that the lock is held */
-  g_mutex_lock (&interface->priv->lock);
-
-  /* unexport from all connections if we're exported anywhere */
-  while (interface->priv->connections != NULL)
-    {
-      ConnectionData *data = interface->priv->connections->data;
-      remove_connection_locked (interface, data->connection);
-    }
-
-  set_object_path_locked (interface, NULL);
-
-  g_mutex_unlock (&interface->priv->lock);
-
-  g_free (interface->priv->hooked_vtable);
+  g_assert (interface->priv->connection == NULL);
+  g_assert (interface->priv->object_path == NULL);
+  g_assert (interface->priv->hooked_vtable == NULL);
 
   if (interface->priv->object != NULL)
     g_object_remove_weak_pointer (G_OBJECT (interface->priv->object), (gpointer *) &interface->priv->object);
-
-  g_mutex_clear (&interface->priv->lock);
-
   G_OBJECT_CLASS (g_dbus_interface_skeleton_parent_class)->finalize (object);
 }
 
@@ -211,11 +176,11 @@ g_dbus_interface_skeleton_class_init (GDBusInterfaceSkeletonClass *klass)
    *
    * Note that this signal is emitted in a thread dedicated to
    * handling the method call so handlers are allowed to perform
-   * blocking IO. This means that it is appropriate to call e.g.
-   * [polkit_authority_check_authorization_sync()](http://hal.freedesktop.org/docs/polkit/PolkitAuthority.html#polkit-authority-check-authorization-sync)
-   * with the
-   * [POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION](http://hal.freedesktop.org/docs/polkit/PolkitAuthority.html#POLKIT-CHECK-AUTHORIZATION-FLAGS-ALLOW-USER-INTERACTION:CAPS)
-   * flag set.
+   * blocking IO. This means that it is appropriate to call
+   * e.g. <ulink
+   * url="http://hal.freedesktop.org/docs/polkit/PolkitAuthority.html#polkit-authority-check-authorization-sync">polkit_authority_check_authorization_sync()</ulink>
+   * with the <ulink
+   * url="http://hal.freedesktop.org/docs/polkit/PolkitAuthority.html#POLKIT-CHECK-AUTHORIZATION-FLAGS-ALLOW-USER-INTERACTION:CAPS">POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION</ulink> flag set.
    *
    * If %FALSE is returned then no further handlers are run and the
    * signal handler must take a reference to @invocation and finish
@@ -245,26 +210,24 @@ g_dbus_interface_skeleton_class_init (GDBusInterfaceSkeletonClass *klass)
    * Since: 2.30
    */
   signals[G_AUTHORIZE_METHOD_SIGNAL] =
-    g_signal_new (I_("g-authorize-method"),
+    g_signal_new ("g-authorize-method",
                   G_TYPE_DBUS_INTERFACE_SKELETON,
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GDBusInterfaceSkeletonClass, g_authorize_method),
                   _g_signal_accumulator_false_handled,
                   NULL,
-                  _g_cclosure_marshal_BOOLEAN__OBJECT,
+                  g_cclosure_marshal_generic,
                   G_TYPE_BOOLEAN,
                   1,
                   G_TYPE_DBUS_METHOD_INVOCATION);
-  g_signal_set_va_marshaller (signals[G_AUTHORIZE_METHOD_SIGNAL],
-                              G_TYPE_FROM_CLASS (klass),
-                              _g_cclosure_marshal_BOOLEAN__OBJECTv);
+
+  g_type_class_add_private (klass, sizeof (GDBusInterfaceSkeletonPrivate));
 }
 
 static void
 g_dbus_interface_skeleton_init (GDBusInterfaceSkeleton *interface)
 {
-  interface->priv = g_dbus_interface_skeleton_get_instance_private (interface);
-  g_mutex_init (&interface->priv->lock);
+  interface->priv = G_TYPE_INSTANCE_GET_PRIVATE (interface, G_TYPE_DBUS_INTERFACE_SKELETON, GDBusInterfaceSkeletonPrivate);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -301,17 +264,11 @@ g_dbus_interface_skeleton_set_flags (GDBusInterfaceSkeleton      *interface_,
                                      GDBusInterfaceSkeletonFlags  flags)
 {
   g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_));
-  g_mutex_lock (&interface_->priv->lock);
   if (interface_->priv->flags != flags)
     {
       interface_->priv->flags = flags;
-      g_mutex_unlock (&interface_->priv->lock);
       g_object_notify (G_OBJECT (interface_), "g-flags");
     }
-  else
-    {
-      g_mutex_unlock (&interface_->priv->lock);
-    }
 }
 
 /**
@@ -336,14 +293,14 @@ g_dbus_interface_skeleton_get_info (GDBusInterfaceSkeleton *interface_)
 }
 
 /**
- * g_dbus_interface_skeleton_get_vtable:
+ * g_dbus_interface_skeleton_get_vtable: (skip)
  * @interface_: A #GDBusInterfaceSkeleton.
  *
  * Gets the interface vtable for the D-Bus interface implemented by
  * @interface_. The returned function pointers should expect @interface_
  * itself to be passed as @user_data.
  *
- * Returns: (not nullable) (transfer none): the vtable of the D-Bus interface implemented by the skeleton
+ * Returns: A #GDBusInterfaceVTable (never %NULL).
  *
  * Since: 2.30
  */
@@ -363,9 +320,7 @@ g_dbus_interface_skeleton_get_vtable (GDBusInterfaceSkeleton *interface_)
  *
  * Gets all D-Bus properties for @interface_.
  *
- * Returns: (transfer full): A #GVariant of type
- * ['a{sv}'][G-VARIANT-TYPE-VARDICT:CAPS].
- * Free with g_variant_unref().
+ * Returns: A new, floating, #GVariant of type <link linkend="G-VARIANT-TYPE-VARDICT:CAPS">'a{sv}'</link>. Free with g_variant_unref().
  *
  * Since: 2.30
  */
@@ -375,7 +330,8 @@ g_dbus_interface_skeleton_get_properties (GDBusInterfaceSkeleton *interface_)
   GVariant *ret;
   g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), NULL);
   ret = G_DBUS_INTERFACE_SKELETON_GET_CLASS (interface_)->get_properties (interface_);
-  return g_variant_take_ref (ret);
+  g_warn_if_fail (g_variant_is_floating (ret));
+  return ret;
 }
 
 /**
@@ -387,7 +343,7 @@ g_dbus_interface_skeleton_get_properties (GDBusInterfaceSkeleton *interface_)
  *
  * For example, an exported D-Bus interface may queue up property
  * changes and emit the
- * `org.freedesktop.DBus.Properties.PropertiesChanged`
+ * <literal>org.freedesktop.DBus.Properties::PropertiesChanged</literal>
  * signal later (e.g. in an idle handler). This technique is useful
  * for collapsing multiple property changes into one.
  *
@@ -413,24 +369,7 @@ static GDBusObject *
 g_dbus_interface_skeleton_get_object (GDBusInterface *interface_)
 {
   GDBusInterfaceSkeleton *interface = G_DBUS_INTERFACE_SKELETON (interface_);
-  GDBusObject *ret;
-  g_mutex_lock (&interface->priv->lock);
-  ret = interface->priv->object;
-  g_mutex_unlock (&interface->priv->lock);
-  return ret;
-}
-
-static GDBusObject *
-g_dbus_interface_skeleton_dup_object (GDBusInterface *interface_)
-{
-  GDBusInterfaceSkeleton *interface = G_DBUS_INTERFACE_SKELETON (interface_);
-  GDBusObject *ret;
-  g_mutex_lock (&interface->priv->lock);
-  ret = interface->priv->object;
-  if (ret != NULL)
-    g_object_ref (ret);
-  g_mutex_unlock (&interface->priv->lock);
-  return ret;
+  return interface->priv->object;
 }
 
 static void
@@ -438,13 +377,11 @@ g_dbus_interface_skeleton_set_object (GDBusInterface *interface_,
                                       GDBusObject    *object)
 {
   GDBusInterfaceSkeleton *interface = G_DBUS_INTERFACE_SKELETON (interface_);
-  g_mutex_lock (&interface->priv->lock);
   if (interface->priv->object != NULL)
     g_object_remove_weak_pointer (G_OBJECT (interface->priv->object), (gpointer *) &interface->priv->object);
   interface->priv->object = object;
   if (object != NULL)
     g_object_add_weak_pointer (G_OBJECT (interface->priv->object), (gpointer *) &interface->priv->object);
-  g_mutex_unlock (&interface->priv->lock);
 }
 
 static void
@@ -452,7 +389,6 @@ dbus_interface_interface_init (GDBusInterfaceIface *iface)
 {
   iface->get_info    = _g_dbus_interface_skeleton_get_info;
   iface->get_object  = g_dbus_interface_skeleton_get_object;
-  iface->dup_object  = g_dbus_interface_skeleton_dup_object;
   iface->set_object  = g_dbus_interface_skeleton_set_object;
 }
 
@@ -460,9 +396,11 @@ dbus_interface_interface_init (GDBusInterfaceIface *iface)
 
 typedef struct
 {
-  gint ref_count;  /* (atomic) */
+  volatile gint ref_count;
+  GDBusInterfaceSkeleton       *interface;
   GDBusInterfaceMethodCallFunc  method_call_func;
-  GDBusMethodInvocation        *invocation;  /* (owned) */
+  GDBusMethodInvocation        *invocation;
+  GMainContext                 *context;
 } DispatchData;
 
 static void
@@ -470,8 +408,9 @@ dispatch_data_unref (DispatchData *data)
 {
   if (g_atomic_int_dec_and_test (&data->ref_count))
     {
-      g_clear_object (&data->invocation);
-      g_slice_free (DispatchData, data);
+      if (data->context != NULL)
+        g_main_context_unref (data->context);
+      g_free (data);
     }
 }
 
@@ -497,38 +436,27 @@ dispatch_invoke_in_context_func (gpointer user_data)
   return FALSE;
 }
 
-static void
-dispatch_in_thread_func (GTask        *task,
-                         gpointer      source_object,
-                         gpointer      task_data,
-                         GCancellable *cancellable)
+static gboolean
+dispatch_in_thread_func (GIOSchedulerJob *job,
+                         GCancellable    *cancellable,
+                         gpointer         user_data)
 {
-  DispatchData *data = task_data;
-  GDBusInterfaceSkeleton *interface = g_task_get_source_object (task);
-  GDBusInterfaceSkeletonFlags flags;
-  GDBusObject *object;
+  DispatchData *data = user_data;
   gboolean authorized;
 
-  g_mutex_lock (&interface->priv->lock);
-  flags = interface->priv->flags;
-  object = interface->priv->object;
-  if (object != NULL)
-    g_object_ref (object);
-  g_mutex_unlock (&interface->priv->lock);
-
   /* first check on the enclosing object (if any), then the interface */
   authorized = TRUE;
-  if (object != NULL)
+  if (data->interface->priv->object != NULL)
     {
-      g_signal_emit_by_name (object,
+      g_signal_emit_by_name (data->interface->priv->object,
                              "authorize-method",
-                             interface,
+                             data->interface,
                              data->invocation,
                              &authorized);
     }
   if (authorized)
     {
-      g_signal_emit (interface,
+      g_signal_emit (data->interface,
                      signals[G_AUTHORIZE_METHOD_SIGNAL],
                      0,
                      data->invocation,
@@ -538,7 +466,7 @@ dispatch_in_thread_func (GTask        *task,
   if (authorized)
     {
       gboolean run_in_thread;
-      run_in_thread = (flags & G_DBUS_INTERFACE_SKELETON_FLAGS_HANDLE_METHOD_INVOCATIONS_IN_THREAD);
+      run_in_thread = (data->interface->priv->flags & G_DBUS_INTERFACE_SKELETON_FLAGS_HANDLE_METHOD_INVOCATIONS_IN_THREAD);
       if (run_in_thread)
         {
           /* might as well just re-use the existing thread */
@@ -554,8 +482,8 @@ dispatch_in_thread_func (GTask        *task,
       else
         {
           /* bah, back to original context */
-          g_main_context_invoke_full (g_task_get_context (task),
-                                      g_task_get_priority (task),
+          g_main_context_invoke_full (data->context,
+                                      G_PRIORITY_DEFAULT,
                                       dispatch_invoke_in_context_func,
                                       dispatch_data_ref (data),
                                       (GDestroyNotify) dispatch_data_unref);
@@ -566,8 +494,7 @@ dispatch_in_thread_func (GTask        *task,
       /* do nothing */
     }
 
-  if (object != NULL)
-    g_object_unref (object);
+  return FALSE;
 }
 
 static void
@@ -579,20 +506,11 @@ g_dbus_interface_method_dispatch_helper (GDBusInterfaceSkeleton       *interface
   gboolean has_default_class_handler;
   gboolean emit_authorized_signal;
   gboolean run_in_thread;
-  GDBusInterfaceSkeletonFlags flags;
-  GDBusObject *object;
 
   g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface));
   g_return_if_fail (method_call_func != NULL);
   g_return_if_fail (G_IS_DBUS_METHOD_INVOCATION (invocation));
 
-  g_mutex_lock (&interface->priv->lock);
-  flags = interface->priv->flags;
-  object = interface->priv->object;
-  if (object != NULL)
-    g_object_ref (object);
-  g_mutex_unlock (&interface->priv->lock);
-
   /* optimization for the common case where
    *
    *  a) no handler is connected and class handler is not overridden (both interface and object); and
@@ -608,11 +526,11 @@ g_dbus_interface_method_dispatch_helper (GDBusInterfaceSkeleton       *interface
   emit_authorized_signal = (has_handlers || !has_default_class_handler);
   if (!emit_authorized_signal)
     {
-      if (object != NULL)
-        emit_authorized_signal = _g_dbus_object_skeleton_has_authorize_method_handlers (G_DBUS_OBJECT_SKELETON (object));
+      if (interface->priv->object != NULL)
+        emit_authorized_signal = _g_dbus_object_skeleton_has_authorize_method_handlers (G_DBUS_OBJECT_SKELETON (interface->priv->object));
     }
 
-  run_in_thread = (flags & G_DBUS_INTERFACE_SKELETON_FLAGS_HANDLE_METHOD_INVOCATIONS_IN_THREAD);
+  run_in_thread = (interface->priv->flags & G_DBUS_INTERFACE_SKELETON_FLAGS_HANDLE_METHOD_INVOCATIONS_IN_THREAD);
   if (!emit_authorized_signal && !run_in_thread)
     {
       method_call_func (g_dbus_method_invocation_get_connection (invocation),
@@ -626,24 +544,21 @@ g_dbus_interface_method_dispatch_helper (GDBusInterfaceSkeleton       *interface
     }
   else
     {
-      GTask *task;
       DispatchData *data;
-
-      data = g_slice_new0 (DispatchData);
+      data = g_new0 (DispatchData, 1);
+      data->interface = interface;
       data->method_call_func = method_call_func;
-      data->invocation = g_object_ref (invocation);
+      data->invocation = invocation;
+      data->context = g_main_context_get_thread_default ();
       data->ref_count = 1;
-
-      task = g_task_new (interface, NULL, NULL, NULL);
-      g_task_set_source_tag (task, g_dbus_interface_method_dispatch_helper);
-      g_task_set_name (task, "[gio] D-Bus interface method dispatch");
-      g_task_set_task_data (task, data, (GDestroyNotify) dispatch_data_unref);
-      g_task_run_in_thread (task, dispatch_in_thread_func);
-      g_object_unref (task);
+      if (data->context != NULL)
+        g_main_context_ref (data->context);
+      g_io_scheduler_push_job (dispatch_in_thread_func,
+                               data,
+                               (GDestroyNotify) dispatch_data_unref,
+                               G_PRIORITY_DEFAULT,
+                               NULL); /* GCancellable* */
     }
-
-  if (object != NULL)
-    g_object_unref (object);
 }
 
 static void
@@ -664,114 +579,13 @@ skeleton_intercept_handle_method_call (GDBusConnection       *connection,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static ConnectionData *
-new_connection (GDBusConnection *connection,
-                guint            registration_id)
-{
-  ConnectionData *data;
-
-  data = g_slice_new0 (ConnectionData);
-  data->connection      = g_object_ref (connection);
-  data->registration_id = registration_id;
-
-  return data;
-}
-
-static void
-free_connection (ConnectionData *data)
-{
-  if (data != NULL)
-    {
-      g_object_unref (data->connection);
-      g_slice_free (ConnectionData, data);
-    }
-}
-
-static gboolean
-add_connection_locked (GDBusInterfaceSkeleton *interface_,
-                       GDBusConnection        *connection,
-                       GError                **error)
-{
-  ConnectionData *data;
-  guint registration_id;
-  gboolean ret = FALSE;
-
-  if (interface_->priv->hooked_vtable == NULL)
-    {
-      /* Hook the vtable since we need to intercept method calls for
-       * ::g-authorize-method and for dispatching in thread vs
-       * context
-       *
-       * We need to wait until subclasses have had time to initialize
-       * properly before building the hooked_vtable, so we create it
-       * once at the last minute.
-       */
-      interface_->priv->hooked_vtable = g_memdup2 (g_dbus_interface_skeleton_get_vtable (interface_), sizeof (GDBusInterfaceVTable));
-      interface_->priv->hooked_vtable->method_call = skeleton_intercept_handle_method_call;
-    }
-
-  registration_id = g_dbus_connection_register_object (connection,
-                                                       interface_->priv->object_path,
-                                                       g_dbus_interface_skeleton_get_info (interface_),
-                                                       interface_->priv->hooked_vtable,
-                                                       interface_,
-                                                       NULL, /* user_data_free_func */
-                                                       error);
-
-  if (registration_id > 0)
-    {
-      data = new_connection (connection, registration_id);
-      interface_->priv->connections = g_slist_append (interface_->priv->connections, data);
-      ret = TRUE;
-    }
-
-  return ret;
-}
-
-static void
-remove_connection_locked (GDBusInterfaceSkeleton *interface_,
-                          GDBusConnection        *connection)
-{
-  ConnectionData *data;
-  GSList *l;
-
-  /* Get the connection in the list and unregister ... */
-  for (l = interface_->priv->connections; l != NULL; l = l->next)
-    {
-      data = l->data;
-      if (data->connection == connection)
-        {
-          g_warn_if_fail (g_dbus_connection_unregister_object (data->connection, data->registration_id));
-          free_connection (data);
-          interface_->priv->connections = g_slist_delete_link (interface_->priv->connections, l);
-          /* we are guaranteed that the connection is only added once, so bail out early */
-          goto out;
-        }
-    }
- out:
-  ;
-}
-
-static void
-set_object_path_locked (GDBusInterfaceSkeleton *interface_,
-                        const gchar            *object_path)
-{
-  if (g_strcmp0 (interface_->priv->object_path, object_path) != 0)
-    {
-      g_free (interface_->priv->object_path);
-      interface_->priv->object_path = g_strdup (object_path);
-    }
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 /**
  * g_dbus_interface_skeleton_get_connection:
  * @interface_: A #GDBusInterfaceSkeleton.
  *
- * Gets the first connection that @interface_ is exported on, if any.
+ * Gets the connection that @interface_ is exported on, if any.
  *
- * Returns: (nullable) (transfer none): A #GDBusConnection or %NULL if @interface_ is
+ * Returns: (transfer none): A #GDBusConnection or %NULL if @interface_ is
  * not exported anywhere. Do not free, the object belongs to @interface_.
  *
  * Since: 2.30
@@ -779,99 +593,8 @@ set_object_path_locked (GDBusInterfaceSkeleton *interface_,
 GDBusConnection *
 g_dbus_interface_skeleton_get_connection (GDBusInterfaceSkeleton *interface_)
 {
-  ConnectionData  *data;
-  GDBusConnection *ret;
-
   g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), NULL);
-  g_mutex_lock (&interface_->priv->lock);
-
-  ret = NULL;
-  if (interface_->priv->connections != NULL)
-    {
-      data = interface_->priv->connections->data;
-      if (data != NULL)
-        ret = data->connection;
-    }
-
-  g_mutex_unlock (&interface_->priv->lock);
-
-  return ret;
-}
-
-/**
- * g_dbus_interface_skeleton_get_connections:
- * @interface_: A #GDBusInterfaceSkeleton.
- *
- * Gets a list of the connections that @interface_ is exported on.
- *
- * Returns: (element-type GDBusConnection) (transfer full): A list of
- *   all the connections that @interface_ is exported on. The returned
- *   list should be freed with g_list_free() after each element has
- *   been freed with g_object_unref().
- *
- * Since: 2.32
- */
-GList *
-g_dbus_interface_skeleton_get_connections (GDBusInterfaceSkeleton *interface_)
-{
-  GList           *connections;
-  GSList          *l;
-  ConnectionData  *data;
-
-  g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), NULL);
-
-  g_mutex_lock (&interface_->priv->lock);
-  connections = NULL;
-
-  for (l = interface_->priv->connections; l != NULL; l = l->next)
-    {
-      data        = l->data;
-      connections = g_list_prepend (connections,
-                                    /* Return a reference to each connection */
-                                    g_object_ref (data->connection));
-    }
-
-  g_mutex_unlock (&interface_->priv->lock);
-
-  return g_list_reverse (connections);
-}
-
-/**
- * g_dbus_interface_skeleton_has_connection:
- * @interface_: A #GDBusInterfaceSkeleton.
- * @connection: A #GDBusConnection.
- *
- * Checks if @interface_ is exported on @connection.
- *
- * Returns: %TRUE if @interface_ is exported on @connection, %FALSE otherwise.
- *
- * Since: 2.32
- */
-gboolean
-g_dbus_interface_skeleton_has_connection (GDBusInterfaceSkeleton     *interface_,
-                                          GDBusConnection            *connection)
-{
-  GSList *l;
-  gboolean ret = FALSE;
-
-  g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), FALSE);
-  g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), FALSE);
-
-  g_mutex_lock (&interface_->priv->lock);
-
-  for (l = interface_->priv->connections; l != NULL; l = l->next)
-    {
-      ConnectionData *data = l->data;
-      if (data->connection == connection)
-        {
-          ret = TRUE;
-          goto out;
-        }
-    }
-
- out:
-  g_mutex_unlock (&interface_->priv->lock);
-  return ret;
+  return interface_->priv->connection;
 }
 
 /**
@@ -880,7 +603,7 @@ g_dbus_interface_skeleton_has_connection (GDBusInterfaceSkeleton     *interface_
  *
  * Gets the object path that @interface_ is exported on, if any.
  *
- * Returns: (nullable): A string owned by @interface_ or %NULL if @interface_ is not exported
+ * Returns: A string owned by @interface_ or %NULL if @interface_ is not exported
  * anywhere. Do not free, the string belongs to @interface_.
  *
  * Since: 2.30
@@ -888,12 +611,8 @@ g_dbus_interface_skeleton_has_connection (GDBusInterfaceSkeleton     *interface_
 const gchar *
 g_dbus_interface_skeleton_get_object_path (GDBusInterfaceSkeleton *interface_)
 {
-  const gchar *ret;
   g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), NULL);
-  g_mutex_lock (&interface_->priv->lock);
-  ret = interface_->priv->object_path;
-  g_mutex_unlock (&interface_->priv->lock);
-  return ret;
+  return interface_->priv->object_path;
 }
 
 /**
@@ -905,13 +624,9 @@ g_dbus_interface_skeleton_get_object_path (GDBusInterfaceSkeleton *interface_)
  *
  * Exports @interface_ at @object_path on @connection.
  *
- * This can be called multiple times to export the same @interface_
- * onto multiple connections however the @object_path provided must be
- * the same for all connections.
- *
  * Use g_dbus_interface_skeleton_unexport() to unexport the object.
  *
- * Returns: %TRUE if the interface was exported on @connection, otherwise %FALSE with
+ * Returns: %TRUE if the interface was exported, other %FALSE with
  * @error set.
  *
  * Since: 2.30
@@ -922,26 +637,49 @@ g_dbus_interface_skeleton_export (GDBusInterfaceSkeleton  *interface_,
                                   const gchar             *object_path,
                                   GError                 **error)
 {
-  gboolean ret = FALSE;
+  gboolean ret;
 
-  g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), FALSE);
-  g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), FALSE);
-  g_return_val_if_fail (g_variant_is_object_path (object_path), FALSE);
-  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+  g_return_val_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_), 0);
+  g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), 0);
+  g_return_val_if_fail (g_variant_is_object_path (object_path), 0);
+  g_return_val_if_fail (error == NULL || *error == NULL, 0);
 
-  /* Assert that the object path is the same for multiple connections here */
-  g_return_val_if_fail (interface_->priv->object_path == NULL ||
-                        g_strcmp0 (interface_->priv->object_path, object_path) == 0, FALSE);
+  ret = FALSE;
+  if (interface_->priv->registration_id > 0)
+    {
+      g_set_error_literal (error,
+                           G_IO_ERROR,
+                           G_IO_ERROR_FAILED, /* TODO: new error code */
+                           "The object is already exported");
+      goto out;
+    }
 
-  g_mutex_lock (&interface_->priv->lock);
+  g_assert (interface_->priv->connection == NULL);
+  g_assert (interface_->priv->object_path == NULL);
+  g_assert (interface_->priv->hooked_vtable == NULL);
 
-  /* Set the object path */
-  set_object_path_locked (interface_, object_path);
+  /* Hook the vtable since we need to intercept method calls for
+   * ::g-authorize-method and for dispatching in thread vs
+   * context
+   */
+  interface_->priv->hooked_vtable = g_memdup (g_dbus_interface_skeleton_get_vtable (interface_), sizeof (GDBusInterfaceVTable));
+  interface_->priv->hooked_vtable->method_call = skeleton_intercept_handle_method_call;
 
-  /* Add the connection */
-  ret = add_connection_locked (interface_, connection, error);
+  interface_->priv->connection = g_object_ref (connection);
+  interface_->priv->object_path = g_strdup (object_path);
+  interface_->priv->registration_id = g_dbus_connection_register_object (connection,
+                                                                         object_path,
+                                                                         g_dbus_interface_skeleton_get_info (interface_),
+                                                                         interface_->priv->hooked_vtable,
+                                                                         interface_,
+                                                                         NULL, /* user_data_free_func */
+                                                                         error);
+  if (interface_->priv->registration_id == 0)
+    goto out;
 
-  g_mutex_unlock (&interface_->priv->lock);
+  ret = TRUE;
+
+ out:
   return ret;
 }
 
@@ -949,10 +687,8 @@ g_dbus_interface_skeleton_export (GDBusInterfaceSkeleton  *interface_,
  * g_dbus_interface_skeleton_unexport:
  * @interface_: A #GDBusInterfaceSkeleton.
  *
- * Stops exporting @interface_ on all connections it is exported on.
- *
- * To unexport @interface_ from only a single connection, use
- * g_dbus_interface_skeleton_unexport_from_connection()
+ * Stops exporting an interface previously exported with
+ * g_dbus_interface_skeleton_export().
  *
  * Since: 2.30
  */
@@ -960,59 +696,21 @@ void
 g_dbus_interface_skeleton_unexport (GDBusInterfaceSkeleton *interface_)
 {
   g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_));
-  g_return_if_fail (interface_->priv->connections != NULL);
-
-  g_mutex_lock (&interface_->priv->lock);
+  g_return_if_fail (interface_->priv->registration_id > 0);
 
+  g_assert (interface_->priv->connection != NULL);
   g_assert (interface_->priv->object_path != NULL);
   g_assert (interface_->priv->hooked_vtable != NULL);
 
-  /* Remove all connections */
-  while (interface_->priv->connections != NULL)
-    {
-      ConnectionData *data = interface_->priv->connections->data;
-      remove_connection_locked (interface_, data->connection);
-    }
+  g_warn_if_fail (g_dbus_connection_unregister_object (interface_->priv->connection,
+                                                       interface_->priv->registration_id));
 
-  /* Unset the object path since there are no connections left */
-  set_object_path_locked (interface_, NULL);
-
-  g_mutex_unlock (&interface_->priv->lock);
-}
-
-
-/**
- * g_dbus_interface_skeleton_unexport_from_connection:
- * @interface_: A #GDBusInterfaceSkeleton.
- * @connection: A #GDBusConnection.
- *
- * Stops exporting @interface_ on @connection.
- *
- * To stop exporting on all connections the interface is exported on,
- * use g_dbus_interface_skeleton_unexport().
- *
- * Since: 2.32
- */
-void
-g_dbus_interface_skeleton_unexport_from_connection (GDBusInterfaceSkeleton *interface_,
-                                                    GDBusConnection        *connection)
-{
-  g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_));
-  g_return_if_fail (G_IS_DBUS_CONNECTION (connection));
-  g_return_if_fail (interface_->priv->connections != NULL);
-
-  g_mutex_lock (&interface_->priv->lock);
-
-  g_assert (interface_->priv->object_path != NULL);
-  g_assert (interface_->priv->hooked_vtable != NULL);
-
-  remove_connection_locked (interface_, connection);
-
-  /* Reset the object path if we removed the last connection */
-  if (interface_->priv->connections == NULL)
-    set_object_path_locked (interface_, NULL);
-
-  g_mutex_unlock (&interface_->priv->lock);
+  g_object_unref (interface_->priv->connection);
+  g_free (interface_->priv->object_path);
+  interface_->priv->connection = NULL;
+  interface_->priv->object_path = NULL;
+  interface_->priv->hooked_vtable = NULL;
+  interface_->priv->registration_id = 0;
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
