@@ -2,12 +2,10 @@
  *
  * Copyright (C) 2008-2010 Red Hat, Inc.
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +13,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author: David Zeuthen <davidz@redhat.com>
  */
@@ -47,7 +47,6 @@
 
 struct _GDBusObjectSkeletonPrivate
 {
-  GMutex lock;
   gchar *object_path;
   GHashTable *map_name_to_iface;
 };
@@ -55,7 +54,7 @@ struct _GDBusObjectSkeletonPrivate
 enum
 {
   PROP_0,
-  PROP_G_OBJECT_PATH
+  PROP_OBJECT_PATH
 };
 
 enum
@@ -69,8 +68,7 @@ static guint signals[LAST_SIGNAL] = {0};
 static void dbus_object_interface_init (GDBusObjectIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GDBusObjectSkeleton, g_dbus_object_skeleton, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GDBusObjectSkeleton)
-                         G_IMPLEMENT_INTERFACE (G_TYPE_DBUS_OBJECT, dbus_object_interface_init))
+                         G_IMPLEMENT_INTERFACE (G_TYPE_DBUS_OBJECT, dbus_object_interface_init));
 
 
 static void
@@ -81,8 +79,6 @@ g_dbus_object_skeleton_finalize (GObject *_object)
   g_free (object->priv->object_path);
   g_hash_table_unref (object->priv->map_name_to_iface);
 
-  g_mutex_clear (&object->priv->lock);
-
   if (G_OBJECT_CLASS (g_dbus_object_skeleton_parent_class)->finalize != NULL)
     G_OBJECT_CLASS (g_dbus_object_skeleton_parent_class)->finalize (_object);
 }
@@ -97,14 +93,12 @@ g_dbus_object_skeleton_get_property (GObject    *_object,
 
   switch (prop_id)
     {
-    case PROP_G_OBJECT_PATH:
-      g_mutex_lock (&object->priv->lock);
-      g_value_set_string (value, object->priv->object_path);
-      g_mutex_unlock (&object->priv->lock);
+    case PROP_OBJECT_PATH:
+      g_value_take_string (value, object->priv->object_path);
       break;
 
     default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (_object, prop_id, pspec);
       break;
     }
 }
@@ -119,12 +113,12 @@ g_dbus_object_skeleton_set_property (GObject       *_object,
 
   switch (prop_id)
     {
-    case PROP_G_OBJECT_PATH:
+    case PROP_OBJECT_PATH:
       g_dbus_object_skeleton_set_object_path (object, g_value_get_string (value));
       break;
 
     default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (_object, prop_id, pspec);
       break;
     }
 }
@@ -149,15 +143,15 @@ g_dbus_object_skeleton_class_init (GDBusObjectSkeletonClass *klass)
   klass->authorize_method = g_dbus_object_skeleton_authorize_method_default;
 
   /**
-   * GDBusObjectSkeleton:g-object-path:
+   * GDBusObjectSkeleton:object-path:
    *
    * The object path where the object is exported.
    *
    * Since: 2.30
    */
   g_object_class_install_property (gobject_class,
-                                   PROP_G_OBJECT_PATH,
-                                   g_param_spec_string ("g-object-path",
+                                   PROP_OBJECT_PATH,
+                                   g_param_spec_string ("object-path",
                                                         "Object Path",
                                                         "The object path where the object is exported",
                                                         NULL,
@@ -175,9 +169,9 @@ g_dbus_object_skeleton_class_init (GDBusObjectSkeletonClass *klass)
    * Emitted when a method is invoked by a remote caller and used to
    * determine if the method call is authorized.
    *
-   * This signal is like #GDBusInterfaceSkeleton's
-   * #GDBusInterfaceSkeleton::g-authorize-method signal,
-   * except that it is for the enclosing object.
+   * This signal is like #GDBusInterfaceSkeleton<!-- -->'s
+   * #GDBusInterfaceSkeleton::g-authorize-method signal, except that it is
+   * for the enclosing object.
    *
    * The default class handler just returns %TRUE.
    *
@@ -186,24 +180,25 @@ g_dbus_object_skeleton_class_init (GDBusObjectSkeletonClass *klass)
    * Since: 2.30
    */
   signals[AUTHORIZE_METHOD_SIGNAL] =
-    g_signal_new (I_("authorize-method"),
+    g_signal_new ("authorize-method",
                   G_TYPE_DBUS_OBJECT_SKELETON,
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GDBusObjectSkeletonClass, authorize_method),
                   _g_signal_accumulator_false_handled,
                   NULL,
-                  NULL,
+                  g_cclosure_marshal_generic,
                   G_TYPE_BOOLEAN,
                   2,
                   G_TYPE_DBUS_INTERFACE_SKELETON,
                   G_TYPE_DBUS_METHOD_INVOCATION);
+
+  g_type_class_add_private (klass, sizeof (GDBusObjectSkeletonPrivate));
 }
 
 static void
 g_dbus_object_skeleton_init (GDBusObjectSkeleton *object)
 {
-  object->priv = g_dbus_object_skeleton_get_instance_private (object);
-  g_mutex_init (&object->priv->lock);
+  object->priv = G_TYPE_INSTANCE_GET_PRIVATE (object, G_TYPE_DBUS_OBJECT_SKELETON, GDBusObjectSkeletonPrivate);
   object->priv->map_name_to_iface = g_hash_table_new_full (g_str_hash,
                                                            g_str_equal,
                                                            g_free,
@@ -225,7 +220,7 @@ g_dbus_object_skeleton_new (const gchar *object_path)
 {
   g_return_val_if_fail (g_variant_is_object_path (object_path), NULL);
   return G_DBUS_OBJECT_SKELETON (g_object_new (G_TYPE_DBUS_OBJECT_SKELETON,
-                                               "g-object-path", object_path,
+                                               "object-path", object_path,
                                                NULL));
 }
 
@@ -244,18 +239,12 @@ g_dbus_object_skeleton_set_object_path (GDBusObjectSkeleton *object,
 {
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (object_path == NULL || g_variant_is_object_path (object_path));
-  g_mutex_lock (&object->priv->lock);
   /* TODO: fail if object is currently exported */
   if (g_strcmp0 (object->priv->object_path, object_path) != 0)
     {
       g_free (object->priv->object_path);
       object->priv->object_path = g_strdup (object_path);
-      g_mutex_unlock (&object->priv->lock);
-      g_object_notify (G_OBJECT (object), "g-object-path");
-    }
-  else
-    {
-      g_mutex_unlock (&object->priv->lock);
+      g_object_notify (G_OBJECT (object), "object-path");
     }
 }
 
@@ -263,11 +252,7 @@ static const gchar *
 g_dbus_object_skeleton_get_object_path (GDBusObject *_object)
 {
   GDBusObjectSkeleton *object = G_DBUS_OBJECT_SKELETON (_object);
-  const gchar *ret;
-  g_mutex_lock (&object->priv->lock);
-  ret = object->priv->object_path;
-  g_mutex_unlock (&object->priv->lock);
-  return ret;
+  return object->priv->object_path;
 }
 
 /**
@@ -290,42 +275,20 @@ g_dbus_object_skeleton_add_interface (GDBusObjectSkeleton     *object,
                                       GDBusInterfaceSkeleton  *interface_)
 {
   GDBusInterfaceInfo *info;
-  GDBusInterface *interface_to_remove;
 
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (G_IS_DBUS_INTERFACE_SKELETON (interface_));
 
-  g_mutex_lock (&object->priv->lock);
-
   info = g_dbus_interface_skeleton_get_info (interface_);
   g_object_ref (interface_);
-
-  interface_to_remove = g_hash_table_lookup (object->priv->map_name_to_iface, info->name);
-  if (interface_to_remove != NULL)
-    {
-      g_object_ref (interface_to_remove);
-      g_warn_if_fail (g_hash_table_remove (object->priv->map_name_to_iface, info->name));
-    }
+  g_dbus_object_skeleton_remove_interface_by_name (object, info->name);
   g_hash_table_insert (object->priv->map_name_to_iface,
                        g_strdup (info->name),
-                       g_object_ref (interface_));
+                       interface_);
   g_dbus_interface_set_object (G_DBUS_INTERFACE (interface_), G_DBUS_OBJECT (object));
-
-  g_mutex_unlock (&object->priv->lock);
-
-  if (interface_to_remove != NULL)
-    {
-      g_dbus_interface_set_object (interface_to_remove, NULL);
-      g_signal_emit_by_name (object,
-                             "interface-removed",
-                             interface_to_remove);
-      g_object_unref (interface_to_remove);
-    }
-
   g_signal_emit_by_name (object,
                          "interface-added",
                          interface_);
-  g_object_unref (interface_);
 }
 
 /**
@@ -347,14 +310,11 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (G_IS_DBUS_INTERFACE (interface_));
 
-  g_mutex_lock (&object->priv->lock);
-
   info = g_dbus_interface_skeleton_get_info (interface_);
 
   other_interface = g_hash_table_lookup (object->priv->map_name_to_iface, info->name);
   if (other_interface == NULL)
     {
-      g_mutex_unlock (&object->priv->lock);
       g_warning ("Tried to remove interface with name %s from object "
                  "at path %s but no such interface exists",
                  info->name,
@@ -362,7 +322,6 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
     }
   else if (other_interface != interface_)
     {
-      g_mutex_unlock (&object->priv->lock);
       g_warning ("Tried to remove interface %p with name %s from object "
                  "at path %s but the object has the interface %p",
                  interface_,
@@ -374,7 +333,6 @@ g_dbus_object_skeleton_remove_interface  (GDBusObjectSkeleton    *object,
     {
       g_object_ref (interface_);
       g_warn_if_fail (g_hash_table_remove (object->priv->map_name_to_iface, info->name));
-      g_mutex_unlock (&object->priv->lock);
       g_dbus_interface_set_object (G_DBUS_INTERFACE (interface_), NULL);
       g_signal_emit_by_name (object,
                              "interface-removed",
@@ -405,23 +363,17 @@ g_dbus_object_skeleton_remove_interface_by_name (GDBusObjectSkeleton *object,
   g_return_if_fail (G_IS_DBUS_OBJECT_SKELETON (object));
   g_return_if_fail (g_dbus_is_interface_name (interface_name));
 
-  g_mutex_lock (&object->priv->lock);
   interface = g_hash_table_lookup (object->priv->map_name_to_iface, interface_name);
   if (interface != NULL)
     {
       g_object_ref (interface);
       g_warn_if_fail (g_hash_table_remove (object->priv->map_name_to_iface, interface_name));
-      g_mutex_unlock (&object->priv->lock);
       g_dbus_interface_set_object (interface, NULL);
       g_signal_emit_by_name (object,
                              "interface-removed",
                              interface);
       g_object_unref (interface);
     }
-  else
-    {
-      g_mutex_unlock (&object->priv->lock);
-    }
 }
 
 static GDBusInterface *
@@ -434,11 +386,9 @@ g_dbus_object_skeleton_get_interface (GDBusObject  *_object,
   g_return_val_if_fail (G_IS_DBUS_OBJECT_SKELETON (object), NULL);
   g_return_val_if_fail (g_dbus_is_interface_name (interface_name), NULL);
 
-  g_mutex_lock (&object->priv->lock);
   ret = g_hash_table_lookup (object->priv->map_name_to_iface, interface_name);
   if (ret != NULL)
     g_object_ref (ret);
-  g_mutex_unlock (&object->priv->lock);
   return ret;
 }
 
@@ -447,15 +397,16 @@ g_dbus_object_skeleton_get_interfaces (GDBusObject *_object)
 {
   GDBusObjectSkeleton *object = G_DBUS_OBJECT_SKELETON (_object);
   GList *ret;
+  GHashTableIter iter;
+  GDBusInterface *interface;
 
   g_return_val_if_fail (G_IS_DBUS_OBJECT_SKELETON (object), NULL);
 
   ret = NULL;
 
-  g_mutex_lock (&object->priv->lock);
-  ret = g_hash_table_get_values (object->priv->map_name_to_iface);
-  g_list_foreach (ret, (GFunc) g_object_ref, NULL);
-  g_mutex_unlock (&object->priv->lock);
+  g_hash_table_iter_init (&iter, object->priv->map_name_to_iface);
+  while (g_hash_table_iter_next (&iter, NULL, (gpointer) &interface))
+    ret = g_list_prepend (ret, g_object_ref (interface));
 
   return ret;
 }
@@ -473,17 +424,14 @@ g_dbus_object_skeleton_get_interfaces (GDBusObject *_object)
 void
 g_dbus_object_skeleton_flush (GDBusObjectSkeleton *object)
 {
-  GList *to_flush, *l;
+  GHashTableIter iter;
+  GDBusInterfaceSkeleton *interface_skeleton;
 
-  g_mutex_lock (&object->priv->lock);
-  to_flush = g_hash_table_get_values (object->priv->map_name_to_iface);
-  g_list_foreach (to_flush, (GFunc) g_object_ref, NULL);
-  g_mutex_unlock (&object->priv->lock);
-
-  for (l = to_flush; l != NULL; l = l->next)
-    g_dbus_interface_skeleton_flush (G_DBUS_INTERFACE_SKELETON (l->data));
-
-  g_list_free_full (to_flush, g_object_unref);
+  g_hash_table_iter_init (&iter, object->priv->map_name_to_iface);
+  while (g_hash_table_iter_next (&iter, NULL, (gpointer) &interface_skeleton))
+    {
+      g_dbus_interface_skeleton_flush (interface_skeleton);
+    }
 }
 
 static void
