@@ -2,12 +2,10 @@
  * 
  * Copyright (C) 2006-2007 Red Hat, Inc.
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +13,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
  */
@@ -27,43 +27,38 @@
 #include "gmountoperation.h"
 #include "gioenumtypes.h"
 #include "glibintl.h"
-#include "gmarshal-internal.h"
 
 
 /**
- * GMountOperation:
+ * SECTION:gmountoperation
+ * @short_description: Object used for authentication and user interaction
+ * @include: gio/gio.h
  *
- * `GMountOperation` provides a mechanism for interacting with the user.
+ * #GMountOperation provides a mechanism for interacting with the user.
  * It can be used for authenticating mountable operations, such as loop
  * mounting files, hard drive partitions or server locations. It can
  * also be used to ask the user questions or show a list of applications
  * preventing unmount or eject operations from completing.
  *
- * Note that `GMountOperation` is used for more than just [iface@Gio.Mount]
- * objects – for example it is also used in [method@Gio.Drive.start] and
- * [method@Gio.Drive.stop].
+ * Note that #GMountOperation is used for more than just #GMount
+ * objects – for example it is also used in g_drive_start() and
+ * g_drive_stop().
  *
  * Users should instantiate a subclass of this that implements all the
  * various callbacks to show the required dialogs, such as
- * [`GtkMountOperation`](https://docs.gtk.org/gtk4/class.MountOperation.html).
- * If no user interaction is desired (for example when automounting
- * filesystems at login time), usually `NULL` can be passed, see each method
- * taking a `GMountOperation` for details.
- *
- * Throughout the API, the term ‘TCRYPT’ is used to mean ‘compatible with TrueCrypt and VeraCrypt’.
- * [TrueCrypt](https://en.wikipedia.org/wiki/TrueCrypt) is a discontinued system for
- * encrypting file containers, partitions or whole disks, typically used with Windows.
- * [VeraCrypt](https://www.veracrypt.fr/) is a maintained fork of TrueCrypt with various
- * improvements and auditing fixes.
+ * #GtkMountOperation. If no user interaction is desired (for example
+ * when automounting filesystems at login time), usually %NULL can be
+ * passed, see each method taking a #GMountOperation for details.
  */
 
+G_DEFINE_TYPE (GMountOperation, g_mount_operation, G_TYPE_OBJECT);
+
 enum {
   ASK_PASSWORD,
   ASK_QUESTION,
   REPLY,
   ABORTED,
   SHOW_PROCESSES,
-  SHOW_UNMOUNT_PROGRESS,
   LAST_SIGNAL
 };
 
@@ -76,9 +71,6 @@ struct _GMountOperationPrivate {
   gboolean anonymous;
   GPasswordSave password_save;
   int choice;
-  gboolean hidden_volume;
-  gboolean system_volume;
-  guint pim;
 };
 
 enum {
@@ -88,14 +80,9 @@ enum {
   PROP_ANONYMOUS,
   PROP_DOMAIN,
   PROP_PASSWORD_SAVE,
-  PROP_CHOICE,
-  PROP_IS_TCRYPT_HIDDEN_VOLUME,
-  PROP_IS_TCRYPT_SYSTEM_VOLUME,
-  PROP_PIM
+  PROP_CHOICE
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GMountOperation, g_mount_operation, G_TYPE_OBJECT)
-
 static void 
 g_mount_operation_set_property (GObject      *object,
                                 guint         prop_id,
@@ -130,7 +117,7 @@ g_mount_operation_set_property (GObject      *object,
 
     case PROP_PASSWORD_SAVE:
       g_mount_operation_set_password_save (operation, 
-                                           (GPasswordSave) g_value_get_enum (value));
+                                           g_value_get_enum (value));
       break;
 
     case PROP_CHOICE:
@@ -138,21 +125,6 @@ g_mount_operation_set_property (GObject      *object,
                                     g_value_get_int (value));
       break;
 
-    case PROP_IS_TCRYPT_HIDDEN_VOLUME:
-      g_mount_operation_set_is_tcrypt_hidden_volume (operation,
-                                                     g_value_get_boolean (value));
-      break;
-
-    case PROP_IS_TCRYPT_SYSTEM_VOLUME:
-      g_mount_operation_set_is_tcrypt_system_volume (operation,
-                                                     g_value_get_boolean (value));
-      break;
-
-    case PROP_PIM:
-        g_mount_operation_set_pim (operation,
-                                   g_value_get_uint (value));
-        break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -191,25 +163,13 @@ g_mount_operation_get_property (GObject    *object,
       break;
 
     case PROP_PASSWORD_SAVE:
-      g_value_set_enum (value, (int) priv->password_save);
+      g_value_set_enum (value, priv->password_save);
       break;
 
     case PROP_CHOICE:
       g_value_set_int (value, priv->choice);
       break;
 
-    case PROP_IS_TCRYPT_HIDDEN_VOLUME:
-      g_value_set_boolean (value, priv->hidden_volume);
-      break;
-
-    case PROP_IS_TCRYPT_SYSTEM_VOLUME:
-      g_value_set_boolean (value, priv->system_volume);
-      break;
-
-    case PROP_PIM:
-      g_value_set_uint (value, priv->pim);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -240,7 +200,7 @@ reply_non_handled_in_idle (gpointer data)
   GMountOperation *op = data;
 
   g_mount_operation_reply (op, G_MOUNT_OPERATION_UNHANDLED);
-  return G_SOURCE_REMOVE;
+  return FALSE;
 }
 
 static void
@@ -279,19 +239,12 @@ show_processes (GMountOperation      *op,
 		   g_object_unref);
 }
 
-static void
-show_unmount_progress (GMountOperation *op,
-                       const gchar     *message,
-                       gint64           time_left,
-                       gint64           bytes_left)
-{
-  /* nothing to do */
-}
-
 static void
 g_mount_operation_class_init (GMountOperationClass *klass)
 {
   GObjectClass *object_class;
+  
+  g_type_class_add_private (klass, sizeof (GMountOperationPrivate));
  
   object_class = G_OBJECT_CLASS (klass);
   object_class->finalize = g_mount_operation_finalize;
@@ -301,7 +254,6 @@ g_mount_operation_class_init (GMountOperationClass *klass)
   klass->ask_password = ask_password;
   klass->ask_question = ask_question;
   klass->show_processes = show_processes;
-  klass->show_unmount_progress = show_unmount_progress;
   
   /**
    * GMountOperation::ask-password:
@@ -323,12 +275,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GMountOperationClass, ask_password),
 		  NULL, NULL,
-		  _g_cclosure_marshal_VOID__STRING_STRING_STRING_FLAGS,
+		  g_cclosure_marshal_generic,
 		  G_TYPE_NONE, 4,
 		  G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_ASK_PASSWORD_FLAGS);
-  g_signal_set_va_marshaller (signals[ASK_PASSWORD],
-                              G_TYPE_FROM_CLASS (object_class),
-                              _g_cclosure_marshal_VOID__STRING_STRING_STRING_FLAGSv);
 		  
   /**
    * GMountOperation::ask-question:
@@ -349,12 +298,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GMountOperationClass, ask_question),
 		  NULL, NULL,
-		  _g_cclosure_marshal_VOID__STRING_BOXED,
+		  g_cclosure_marshal_generic,
 		  G_TYPE_NONE, 2,
 		  G_TYPE_STRING, G_TYPE_STRV);
-  g_signal_set_va_marshaller (signals[ASK_QUESTION],
-                              G_TYPE_FROM_CLASS (object_class),
-                              _g_cclosure_marshal_VOID__STRING_BOXEDv);
 		  
   /**
    * GMountOperation::reply:
@@ -369,7 +315,7 @@ g_mount_operation_class_init (GMountOperationClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GMountOperationClass, reply),
 		  NULL, NULL,
-		  NULL,
+		  g_cclosure_marshal_VOID__ENUM,
 		  G_TYPE_NONE, 1,
 		  G_TYPE_MOUNT_OPERATION_RESULT);
 
@@ -390,15 +336,14 @@ g_mount_operation_class_init (GMountOperationClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GMountOperationClass, aborted),
 		  NULL, NULL,
-		  NULL,
+		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
 
   /**
    * GMountOperation::show-processes:
    * @op: a #GMountOperation.
    * @message: string containing a message to display to the user.
-   * @processes: (element-type GPid): an array of #GPid for processes
-   *   blocking the operation.
+   * @processes: an array of #GPid for processes blocking the operation.
    * @choices: an array of strings for each possible choice.
    *
    * Emitted when one or more processes are blocking an operation
@@ -422,54 +367,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GMountOperationClass, show_processes),
 		  NULL, NULL,
-		  _g_cclosure_marshal_VOID__STRING_BOXED_BOXED,
+		  g_cclosure_marshal_generic,
 		  G_TYPE_NONE, 3,
 		  G_TYPE_STRING, G_TYPE_ARRAY, G_TYPE_STRV);
-  g_signal_set_va_marshaller (signals[SHOW_PROCESSES],
-                              G_TYPE_FROM_CLASS (object_class),
-                              _g_cclosure_marshal_VOID__STRING_BOXED_BOXEDv);
-
-  /**
-   * GMountOperation::show-unmount-progress:
-   * @op: a #GMountOperation:
-   * @message: string containing a message to display to the user
-   * @time_left: the estimated time left before the operation completes,
-   *     in microseconds, or -1
-   * @bytes_left: the amount of bytes to be written before the operation
-   *     completes (or -1 if such amount is not known), or zero if the operation
-   *     is completed
-   *
-   * Emitted when an unmount operation has been busy for more than some time
-   * (typically 1.5 seconds).
-   *
-   * When unmounting or ejecting a volume, the kernel might need to flush
-   * pending data in its buffers to the volume stable storage, and this operation
-   * can take a considerable amount of time. This signal may be emitted several
-   * times as long as the unmount operation is outstanding, and then one
-   * last time when the operation is completed, with @bytes_left set to zero.
-   *
-   * Implementations of GMountOperation should handle this signal by
-   * showing an UI notification, and then dismiss it, or show another notification
-   * of completion, when @bytes_left reaches zero.
-   *
-   * If the message contains a line break, the first line should be
-   * presented as a heading. For example, it may be used as the
-   * primary text in a #GtkMessageDialog.
-   *
-   * Since: 2.34
-   */
-  signals[SHOW_UNMOUNT_PROGRESS] =
-    g_signal_new (I_("show-unmount-progress"),
-                  G_TYPE_FROM_CLASS (object_class),
-                  G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (GMountOperationClass, show_unmount_progress),
-                  NULL, NULL,
-                  _g_cclosure_marshal_VOID__STRING_INT64_INT64,
-                  G_TYPE_NONE, 3,
-                  G_TYPE_STRING, G_TYPE_INT64, G_TYPE_INT64);
-  g_signal_set_va_marshaller (signals[SHOW_UNMOUNT_PROGRESS],
-                              G_TYPE_FROM_CLASS (object_class),
-                              _g_cclosure_marshal_VOID__STRING_INT64_INT64v);
 
   /**
    * GMountOperation:username:
@@ -479,7 +379,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */ 
   g_object_class_install_property (object_class,
                                    PROP_USERNAME,
-                                   g_param_spec_string ("username", NULL, NULL,
+                                   g_param_spec_string ("username",
+                                                        P_("Username"),
+                                                        P_("The user name"),
                                                         NULL,
                                                         G_PARAM_READWRITE|
                                                         G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
@@ -492,7 +394,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */ 
   g_object_class_install_property (object_class,
                                    PROP_PASSWORD,
-                                   g_param_spec_string ("password", NULL, NULL,
+                                   g_param_spec_string ("password",
+                                                        P_("Password"),
+                                                        P_("The password"),
                                                         NULL,
                                                         G_PARAM_READWRITE|
                                                         G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
@@ -504,7 +408,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */
   g_object_class_install_property (object_class,
                                    PROP_ANONYMOUS,
-                                   g_param_spec_boolean ("anonymous", NULL, NULL,
+                                   g_param_spec_boolean ("anonymous",
+                                                         P_("Anonymous"),
+                                                         P_("Whether to use an anonymous user"),
                                                          FALSE,
                                                          G_PARAM_READWRITE|
                                                          G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
@@ -516,7 +422,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */ 
   g_object_class_install_property (object_class,
                                    PROP_DOMAIN,
-                                   g_param_spec_string ("domain", NULL, NULL,
+                                   g_param_spec_string ("domain",
+                                                        P_("Domain"),
+                                                        P_("The domain of the mount operation"),
                                                         NULL,
                                                         G_PARAM_READWRITE|
                                                         G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
@@ -528,7 +436,9 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */ 
   g_object_class_install_property (object_class,
                                    PROP_PASSWORD_SAVE,
-                                   g_param_spec_enum ("password-save", NULL, NULL,
+                                   g_param_spec_enum ("password-save",
+                                                      P_("Password save"),
+                                                      P_("How passwords should be saved"),
                                                       G_TYPE_PASSWORD_SAVE,
                                                       G_PASSWORD_SAVE_NEVER,
                                                       G_PARAM_READWRITE|
@@ -542,64 +452,20 @@ g_mount_operation_class_init (GMountOperationClass *klass)
    */ 
   g_object_class_install_property (object_class,
                                    PROP_CHOICE,
-                                   g_param_spec_int ("choice", NULL, NULL,
+                                   g_param_spec_int ("choice",
+                                                     P_("Choice"),
+                                                     P_("The users choice"),
                                                      0, G_MAXINT, 0,
                                                      G_PARAM_READWRITE|
                                                      G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
-
-  /**
-   * GMountOperation:is-tcrypt-hidden-volume:
-   *
-   * Whether the device to be unlocked is a TCRYPT hidden volume.
-   * See [the VeraCrypt documentation](https://www.veracrypt.fr/en/Hidden%20Volume.html).
-   *
-   * Since: 2.58
-   */
-  g_object_class_install_property (object_class,
-                                   PROP_IS_TCRYPT_HIDDEN_VOLUME,
-                                   g_param_spec_boolean ("is-tcrypt-hidden-volume", NULL, NULL,
-                                                         FALSE,
-                                                         G_PARAM_READWRITE|
-                                                         G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
-
-  /**
-  * GMountOperation:is-tcrypt-system-volume:
-  *
-  * Whether the device to be unlocked is a TCRYPT system volume.
-  * In this context, a system volume is a volume with a bootloader
-  * and operating system installed. This is only supported for Windows
-  * operating systems. For further documentation, see
-  * [the VeraCrypt documentation](https://www.veracrypt.fr/en/System%20Encryption.html).
-  *
-  * Since: 2.58
-  */
-  g_object_class_install_property (object_class,
-                                   PROP_IS_TCRYPT_SYSTEM_VOLUME,
-                                   g_param_spec_boolean ("is-tcrypt-system-volume", NULL, NULL,
-                                                         FALSE,
-                                                         G_PARAM_READWRITE|
-                                                         G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
-
-  /**
-  * GMountOperation:pim:
-  *
-  * The VeraCrypt PIM value, when unlocking a VeraCrypt volume. See
-  * [the VeraCrypt documentation](https://www.veracrypt.fr/en/Personal%20Iterations%20Multiplier%20(PIM).html).
-  *
-  * Since: 2.58
-  */
-  g_object_class_install_property (object_class,
-                                   PROP_PIM,
-                                   g_param_spec_uint ("pim", NULL, NULL,
-                                                      0, G_MAXUINT, 0,
-                                                      G_PARAM_READWRITE|
-                                                      G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB));
 }
 
 static void
 g_mount_operation_init (GMountOperation *operation)
 {
-  operation->priv = g_mount_operation_get_instance_private (operation);
+  operation->priv = G_TYPE_INSTANCE_GET_PRIVATE (operation,
+						 G_TYPE_MOUNT_OPERATION,
+						 GMountOperationPrivate);
 }
 
 /**
@@ -616,12 +482,12 @@ g_mount_operation_new (void)
 }
 
 /**
- * g_mount_operation_get_username:
+ * g_mount_operation_get_username
  * @op: a #GMountOperation.
  * 
  * Get the user name from the mount operation.
  *
- * Returns: (nullable): a string containing the user name.
+ * Returns: a string containing the user name.
  **/
 const char *
 g_mount_operation_get_username (GMountOperation *op)
@@ -633,7 +499,7 @@ g_mount_operation_get_username (GMountOperation *op)
 /**
  * g_mount_operation_set_username:
  * @op: a #GMountOperation.
- * @username: (nullable): input username.
+ * @username: input username.
  *
  * Sets the user name within @op to @username.
  **/
@@ -653,7 +519,7 @@ g_mount_operation_set_username (GMountOperation *op,
  *
  * Gets a password from the mount operation. 
  *
- * Returns: (nullable): a string containing the password within @op.
+ * Returns: a string containing the password within @op.
  **/
 const char *
 g_mount_operation_get_password (GMountOperation *op)
@@ -665,7 +531,7 @@ g_mount_operation_get_password (GMountOperation *op)
 /**
  * g_mount_operation_set_password:
  * @op: a #GMountOperation.
- * @password: (nullable): password to set.
+ * @password: password to set.
  * 
  * Sets the mount operation's password to @password.  
  *
@@ -724,7 +590,7 @@ g_mount_operation_set_anonymous (GMountOperation *op,
  * 
  * Gets the domain of the mount operation.
  * 
- * Returns: (nullable): a string set to the domain.
+ * Returns: a string set to the domain. 
  **/
 const char *
 g_mount_operation_get_domain (GMountOperation *op)
@@ -736,7 +602,7 @@ g_mount_operation_get_domain (GMountOperation *op)
 /**
  * g_mount_operation_set_domain:
  * @op: a #GMountOperation.
- * @domain: (nullable): the domain to set.
+ * @domain: the domain to set.
  * 
  * Sets the mount operation's domain. 
  **/  
@@ -796,7 +662,7 @@ g_mount_operation_set_password_save (GMountOperation *op,
  * Gets a choice from the mount operation.
  *
  * Returns: an integer containing an index of the user's choice from 
- * the choice's list, or `0`.
+ * the choice's list, or %0.
  **/
 int
 g_mount_operation_get_choice (GMountOperation *op)
@@ -826,130 +692,6 @@ g_mount_operation_set_choice (GMountOperation *op,
     }
 }
 
-/**
- * g_mount_operation_get_is_tcrypt_hidden_volume:
- * @op: a #GMountOperation.
- *
- * Check to see whether the mount operation is being used
- * for a TCRYPT hidden volume.
- *
- * Returns: %TRUE if mount operation is for hidden volume.
- *
- * Since: 2.58
- **/
-gboolean
-g_mount_operation_get_is_tcrypt_hidden_volume (GMountOperation *op)
-{
-  g_return_val_if_fail (G_IS_MOUNT_OPERATION (op), FALSE);
-  return op->priv->hidden_volume;
-}
-
-/**
- * g_mount_operation_set_is_tcrypt_hidden_volume:
- * @op: a #GMountOperation.
- * @hidden_volume: boolean value.
- *
- * Sets the mount operation to use a hidden volume if @hidden_volume is %TRUE.
- *
- * Since: 2.58
- **/
-void
-g_mount_operation_set_is_tcrypt_hidden_volume (GMountOperation *op,
-                                               gboolean hidden_volume)
-{
-  GMountOperationPrivate *priv;
-  g_return_if_fail (G_IS_MOUNT_OPERATION (op));
-  priv = op->priv;
-
-  if (priv->hidden_volume != hidden_volume)
-    {
-      priv->hidden_volume = hidden_volume;
-      g_object_notify (G_OBJECT (op), "is-tcrypt-hidden-volume");
-    }
-}
-
-/**
- * g_mount_operation_get_is_tcrypt_system_volume:
- * @op: a #GMountOperation.
- *
- * Check to see whether the mount operation is being used
- * for a TCRYPT system volume.
- *
- * Returns: %TRUE if mount operation is for system volume.
- *
- * Since: 2.58
- **/
-gboolean
-g_mount_operation_get_is_tcrypt_system_volume (GMountOperation *op)
-{
-  g_return_val_if_fail (G_IS_MOUNT_OPERATION (op), FALSE);
-  return op->priv->system_volume;
-}
-
-/**
- * g_mount_operation_set_is_tcrypt_system_volume:
- * @op: a #GMountOperation.
- * @system_volume: boolean value.
- *
- * Sets the mount operation to use a system volume if @system_volume is %TRUE.
- *
- * Since: 2.58
- **/
-void
-g_mount_operation_set_is_tcrypt_system_volume (GMountOperation *op,
-                                               gboolean system_volume)
-{
-  GMountOperationPrivate *priv;
-  g_return_if_fail (G_IS_MOUNT_OPERATION (op));
-  priv = op->priv;
-
-  if (priv->system_volume != system_volume)
-    {
-      priv->system_volume = system_volume;
-      g_object_notify (G_OBJECT (op), "is-tcrypt-system-volume");
-    }
-}
-
-/**
- * g_mount_operation_get_pim:
- * @op: a #GMountOperation.
- *
- * Gets a PIM from the mount operation.
- *
- * Returns: The VeraCrypt PIM within @op.
- *
- * Since: 2.58
- **/
-guint
-g_mount_operation_get_pim (GMountOperation *op)
-{
-  g_return_val_if_fail (G_IS_MOUNT_OPERATION (op), 0);
-  return op->priv->pim;
-}
-
-/**
- * g_mount_operation_set_pim:
- * @op: a #GMountOperation.
- * @pim: an unsigned integer.
- *
- * Sets the mount operation's PIM to @pim.
- *
- * Since: 2.58
- **/
-void
-g_mount_operation_set_pim (GMountOperation *op,
-                           guint pim)
-{
-  GMountOperationPrivate *priv;
-  g_return_if_fail (G_IS_MOUNT_OPERATION (op));
-  priv = op->priv;
-  if (priv->pim != pim)
-    {
-      priv->pim = pim;
-      g_object_notify (G_OBJECT (op), "pim");
-    }
-}
-
 /**
  * g_mount_operation_reply:
  * @op: a #GMountOperation
